==> qxmledit-0.8.8-1-src.tgz: qxmledit-0.8.8-1/test/sqlliteaccess.h <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2012 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/


#ifndef SQLLITEACCESS_H
#define SQLLITEACCESS_H

#include <QTemporaryFile>
#include "../src/sessions/data_access/sqllitedataaccess.h"
#include "../src/sessions/data_access/sqllitedataaccessprivate.h"
#include "../src/services/loghandler.h"

class SQLLiteTestAccess
{
public:
    LogHandler logHandler;
    SQLLiteDataAccess *access;
    QTemporaryFile tempFile;
    QString dbFileName;

    SQLLiteTestAccess();
    ~SQLLiteTestAccess();

    bool init();
};

#endif // SQLLITEACCESS_H

==> qxmledit-0.9.9.2-src.tgz: qxmledit-0.9.9.2/test/sqlliteaccess.h <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2012 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/


#ifndef SQLLITEACCESS_H
#define SQLLITEACCESS_H

#include <QTemporaryFile>
#include "../src/sessions/data_access/sqllitedataaccess.h"
#include "../src/sessions/data_access/sqllitedataaccessprivate.h"
#include "../src/services/loghandler.h"

class SQLLiteTestAccess
{
    bool _isOpenAccess ;
public:
    LogHandler logHandler;
    SQLLiteDataAccess *access;
    QTemporaryFile tempFile;
    QString dbFileName;

    SQLLiteTestAccess(const bool openAccess=true);
    ~SQLLiteTestAccess();

    bool init();
};

#endif // SQLLITEACCESS_H
